@@ -152,7 +152,7 @@ go_test() {
 
   echo "🧪 ${X}Test"
   set +e
-  go test -v ./pkg/... >$test_output 2>&1
+  go test -v ./cmd/... ./pkg/... >$test_output 2>&1
   local err=$?
   if [ $err -ne 0 ]; then
     echo "🔥 ${red}Failure${reset}"
@@ -170,7 +170,7 @@ check_license() {
 
   local check_output=$(mktemp /tmp/kn-client-licence-check.XXXXXX)
   for ext in "${extensions_to_check[@]}"; do
-    find . -name "*.$ext" -a \! -path "./vendor/*" -a \! -path "./.*" -print0 |
+    find . -name "*.$ext" -a \! -path "./vendor/*" -a \! -path "./.*" -a \! -path "./third_party/*" -print0 |
       while IFS= read -r -d '' path; do
         for rword in "${required_keywords[@]}"; do
           if ! grep -q "$rword" "$path"; then
@@ -284,6 +284,8 @@ cross_build() {
   GOOS=darwin GOARCH=amd64 go build -mod=vendor -ldflags "${ld_flags}" -o ./kn-darwin-amd64 ./cmd/... || failed=1
   echo "   🎠 kn-windows-amd64.exe"
   GOOS=windows GOARCH=amd64 go build -mod=vendor -ldflags "${ld_flags}" -o ./kn-windows-amd64.exe ./cmd/... || failed=1
+  #echo "   Z  kn-linux-s390x"
+  #GOOS=linux GOARCH=s390x go build -mod=vendor -ldflags "${ld_flags}" -o ./kn-linux-s390x ./cmd/... || failed=1
 
   return ${failed}
 }
@@ -298,7 +300,7 @@ apply_emoji_fixes() {
   if [ -n "${ITERM_PROFILE:-}" ]; then
     S=" "
     # This issue has been fixed with iTerm2 3.3.7, so let's check for this
-    # We can remove this code alltogether if iTerm2 3.3.7 is in common usage everywhere
+    # We can remove this code altogether if iTerm2 3.3.7 is in common usage everywhere
     if [ -n "${TERM_PROGRAM_VERSION}" ]; then
       args=$(echo $TERM_PROGRAM_VERSION | sed -e 's#[^0-9]*\([0-9]*\)[.]\([0-9]*\)[.]\([0-9]*\)\([0-9A-Za-z-]*\)#\1 \2 \3#')
       expanded=$(printf '%03d%03d%03d' $args)
