@@ -19,23 +19,21 @@
 release=$1
 target=$2
 
+ROOT_DIR=$(dirname "$0")/../..
+source "$ROOT_DIR/openshift/release/common.sh"
+
 # Custom files
 custom_files=$(cat <<EOT | tr '\n' ' '
 openshift
 OWNERS_ALIASES
 OWNERS
 Makefile
-Dockerfile.rhel
-Dockerfile.cliartifacts.rhel
 package_cliartifacts.sh
-container.yaml
-content_sets.yaml
 openshift-serverless-clients.spec
 serve.py
 EOT
 )
 
-
 # Fetch the latest tags and checkout a new branch from the wanted tag.
 git fetch upstream --tags
 git checkout -b "$target" "$release"
@@ -45,3 +43,7 @@ git fetch openshift master
 git checkout openshift/master $custom_files
 git add $custom_files
 git commit -m "Add openshift specific files."
+
+# Fetch and generate required resources to enable faas as a plugin.
+# As a result two git commits are added. 
+update_faas_plugin
