@@ -16,6 +16,7 @@ package service
 
 import (
 	"fmt"
+	"strconv"
 	"strings"
 
 	"github.com/spf13/cobra"
@@ -27,6 +28,8 @@ import (
 	knflags "knative.dev/client/pkg/kn/flags"
 	servinglib "knative.dev/client/pkg/serving"
 	"knative.dev/client/pkg/util"
+	network "knative.dev/networking/pkg"
+	"knative.dev/serving/pkg/apis/autoscaling"
 	"knative.dev/serving/pkg/apis/serving"
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 )
@@ -48,7 +51,10 @@ type ConfigurationEditFlags struct {
 	LabelsRevision         []string
 	RevisionName           string
 	Annotations            []string
+	AnnotationsService     []string
+	AnnotationsRevision    []string
 	ClusterLocal           bool
+	ScaleInit              int
 
 	// Preferences about how to do the action.
 	LockToDigest         bool
@@ -123,13 +129,13 @@ func (p *ConfigurationEditFlags) addSharedFlags(command *cobra.Command) {
 		"Service label to set. name=value; you may provide this flag "+
 			"any number of times to set multiple labels. "+
 			"To unset, specify the label name followed by a \"-\" (e.g., name-). This flag takes "+
-			"precedence over \"label\" flag.")
+			"precedence over the \"label\" flag.")
 	p.markFlagMakesRevision("label-service")
 	command.Flags().StringArrayVarP(&p.LabelsRevision, "label-revision", "", []string{},
 		"Revision label to set. name=value; you may provide this flag "+
 			"any number of times to set multiple labels. "+
 			"To unset, specify the label name followed by a \"-\" (e.g., name-). This flag takes "+
-			"precedence over \"label\" flag.")
+			"precedence over the \"label\" flag.")
 	p.markFlagMakesRevision("label-revision")
 
 	command.Flags().StringVar(&p.RevisionName, "revision-name", "{{.Service}}-{{.Random 5}}-{{.Generation}}",
@@ -145,10 +151,27 @@ func (p *ConfigurationEditFlags) addSharedFlags(command *cobra.Command) {
 	// Don't mark as changing the revision.
 
 	command.Flags().StringArrayVarP(&p.Annotations, "annotation", "a", []string{},
-		"Service annotation to set. name=value; you may provide this flag "+
+		"Annotations to set for both Service and Revision. name=value; you may provide this flag "+
 			"any number of times to set multiple annotations. "+
 			"To unset, specify the annotation name followed by a \"-\" (e.g., name-).")
 	p.markFlagMakesRevision("annotation")
+
+	command.Flags().StringArrayVarP(&p.AnnotationsService, "annotation-service", "", []string{},
+		"Service annotation to set. name=value; you may provide this flag "+
+			"any number of times to set multiple annotations. "+
+			"To unset, specify the annotation name followed by a \"-\" (e.g., name-). This flag takes "+
+			"precedence over the \"annotation\" flag.")
+	p.markFlagMakesRevision("annotation-service")
+
+	command.Flags().StringArrayVarP(&p.AnnotationsRevision, "annotation-revision", "", []string{},
+		"Revision annotation to set. name=value; you may provide this flag "+
+			"any number of times to set multiple annotations. "+
+			"To unset, specify the annotation name followed by a \"-\" (e.g., name-). This flag takes "+
+			"precedence over the \"annotation\" flag.")
+	p.markFlagMakesRevision("annotation-revision")
+
+	command.Flags().IntVar(&p.ScaleInit, "scale-init", 0, "Initial number of replicas with which a service starts. Can be 0 or a positive integer.")
+	p.markFlagMakesRevision("scale-init")
 }
 
 // AddUpdateFlags adds the flags specific to update.
@@ -376,10 +399,10 @@ func (p *ConfigurationEditFlags) Apply(
 
 	if cmd.Flags().Changed("cluster-local") || cmd.Flags().Changed("no-cluster-local") {
 		if p.ClusterLocal {
-			labels := servinglib.UpdateLabels(service.ObjectMeta.Labels, map[string]string{serving.VisibilityLabelKey: serving.VisibilityClusterLocal}, []string{})
+			labels := servinglib.UpdateLabels(service.ObjectMeta.Labels, map[string]string{network.VisibilityLabelKey: serving.VisibilityClusterLocal}, []string{})
 			service.ObjectMeta.Labels = labels // In case service.ObjectMeta.Labels was nil
 		} else {
-			labels := servinglib.UpdateLabels(service.ObjectMeta.Labels, map[string]string{}, []string{serving.VisibilityLabelKey})
+			labels := servinglib.UpdateLabels(service.ObjectMeta.Labels, map[string]string{}, []string{network.VisibilityLabelKey})
 			service.ObjectMeta.Labels = labels // In case service.ObjectMeta.Labels was nil
 		}
 	}
@@ -401,17 +424,52 @@ func (p *ConfigurationEditFlags) Apply(
 		}
 	}
 
-	if cmd.Flags().Changed("annotation") {
-		annotationsMap, err := util.MapFromArrayAllowingSingles(p.Annotations, "=")
+	if cmd.Flags().Changed("annotation") || cmd.Flags().Changed("annotation-service") || cmd.Flags().Changed("annotation-revision") {
+		annotationsAllMap, err := util.MapFromArrayAllowingSingles(p.Annotations, "=")
 		if err != nil {
 			return fmt.Errorf("Invalid --annotation: %w", err)
 		}
+		annotationRevisionFlagMap, err := util.MapFromArrayAllowingSingles(p.AnnotationsRevision, "=")
+		if err != nil {
+			return fmt.Errorf("Invalid --annotation-revision: %w", err)
+		}
+		annotationServiceFlagMap, err := util.MapFromArrayAllowingSingles(p.AnnotationsService, "=")
+		if err != nil {
+			return fmt.Errorf("Invalid --annotation-service: %w", err)
+		}
 
-		annotationsToRemove := util.ParseMinusSuffix(annotationsMap)
-		err = servinglib.UpdateAnnotations(service, template, annotationsMap, annotationsToRemove)
+		annotationsToRemove := util.ParseMinusSuffix(annotationsAllMap)
+
+		revisionAnnotations := make(util.StringMap)
+		revisionAnnotations.Merge(annotationsAllMap)
+		revisionAnnotations.Merge(annotationRevisionFlagMap)
+		err = servinglib.UpdateRevisionTemplateAnnotations(template, revisionAnnotations, annotationsToRemove)
 		if err != nil {
 			return err
 		}
+
+		serviceAnnotations := make(util.StringMap)
+
+		// Service Annotations can't contain Autoscaling ones
+
+		for key, value := range annotationsAllMap {
+			if !strings.HasPrefix(key, autoscaling.GroupName) {
+				serviceAnnotations[key] = value
+			}
+		}
+
+		for key, value := range annotationServiceFlagMap {
+			if strings.HasPrefix(key, autoscaling.GroupName) {
+				return fmt.Errorf("service can not have auto-scaling related annotation: %s , please update using '--annotation-revision'", key)
+			}
+			serviceAnnotations[key] = value
+		}
+
+		err = servinglib.UpdateServiceAnnotations(service, serviceAnnotations, annotationsToRemove)
+		if err != nil {
+			return err
+		}
+
 	}
 
 	if cmd.Flags().Changed("service-account") {
@@ -429,6 +487,26 @@ func (p *ConfigurationEditFlags) Apply(
 		servinglib.UpdateUser(template, p.PodSpecFlags.User)
 	}
 
+	if cmd.Flags().Changed("scale-init") {
+		containsAnnotation := func(annotationList []string, annotation string) bool {
+			for _, element := range annotationList {
+				if strings.Contains(element, annotation) {
+					return true
+				}
+			}
+			return false
+		}
+
+		if cmd.Flags().Changed("annotation") && containsAnnotation(p.Annotations, autoscaling.InitialScaleAnnotationKey) {
+			return fmt.Errorf("only one of the --scale-init or --annotation %s can be specified", autoscaling.InitialScaleAnnotationKey)
+		}
+		// Autoscaling annotations are only applicable on Revision Template, not Service
+		err = servinglib.UpdateRevisionTemplateAnnotation(template, autoscaling.InitialScaleAnnotationKey, strconv.Itoa(p.ScaleInit))
+		if err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
