@@ -32,7 +32,7 @@ func NewPingDescribeCommand(p *commands.KnParams) *cobra.Command {
 
 	pingDescribe := &cobra.Command{
 		Use:   "describe NAME",
-		Short: "Show details of a Ping source",
+		Short: "Show details of a ping source",
 		Example: `
   # Describe a Ping source with name 'myping'
   kn source ping describe myping`,
@@ -119,7 +119,7 @@ func writePingSource(dw printers.PrefixWriter, source *v1alpha2.PingSource, prin
 
 func writeCeOverrides(dw printers.PrefixWriter, ceOverrides map[string]string) {
 	subDw := dw.WriteAttribute("CloudEvent Overrides", "")
-	var keys []string
+	keys := make([]string, 0, len(ceOverrides))
 	for k := range ceOverrides {
 		keys = append(keys, k)
 	}
