@@ -28,8 +28,9 @@ const (
 // NewTriggerCommand to create trigger command group
 func NewTriggerCommand(p *commands.KnParams) *cobra.Command {
 	triggerCmd := &cobra.Command{
-		Use:   "trigger",
-		Short: "Manage event triggers",
+		Use:     "trigger",
+		Short:   "Manage event triggers (alias: triggers)",
+		Aliases: []string{"triggers"},
 	}
 	triggerCmd.AddCommand(NewTriggerCreateCommand(p))
 	triggerCmd.AddCommand(NewTriggerUpdateCommand(p))
